@@ -3,6 +3,7 @@ from emannotationschemas.schemas.synapse import PlasticSynapse
 from emannotationschemas.schemas.synapse import BuhmannSynapseSchema
 from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
 from emannotationschemas.schemas.synapse import NoCleftSynapse
+from emannotationschemas.schemas.bouton_shape import BoutonShape
 from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
 from emannotationschemas.schemas.functional_coregistration import (
     FunctionalCoregistration,
@@ -29,16 +30,19 @@ from emannotationschemas.schemas.proofreading import (
     ProofreadStatus,
     ProofreadingBoolStatusUser,
 )
+from emannotationschemas.schemas.neuropil import FlyNeuropil
+
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "3.4.1"
+__version__ = "3.5.3"
 
 type_mapping = {
     "synapse": SynapseSchema,
     "nocleft_synapse": NoCleftSynapse,
     "fly_synapse": BuhmannSynapseSchema,
     "fly_nt_synapse": BuhmannEcksteinSynapseSchema,
+    "bouton_shape": BoutonShape,
     "presynaptic_bouton_type": PresynapticBoutonType,
     "postsynaptic_compartment": PostsynapticCompartment,
     "microns_func_coreg": FunctionalCoregistration,
@@ -57,6 +61,7 @@ type_mapping = {
     "proofread_status": ProofreadStatus,
     "compartment_proofread_status": CompartmentProofreadStatus,
     "proofreading_boolstatus_user": ProofreadingBoolStatusUser,
+    "fly_neuropil": FlyNeuropil,
 }
 
 
