@@ -40,3 +40,17 @@ class CompartmentProofreadStatus(PointWithValid):
         validate=validate.OneOf(proofread_choices),
         description=f"Proofread status of the axon only. {options_text}",
     )
+
+
+class ProofreadingBoolStatus(PointWithValid):
+    proofread = fields.Bool(
+        required=True,
+        description=f"Proofread status of cell.",
+    )
+
+
+class ProofreadingBoolStatusUser(ProofreadingBoolStatus):
+    user_id = fields.Int(
+        required=True,
+        description=f"User who assessed the proofreading status.",
+    )
